diff --git a/components/WerteForm.tsx b/components/WerteForm.tsx
index 6a9b130..3c753dd 100644
--- a/components/WerteForm.tsx
+++ b/components/WerteForm.tsx
@@ -196,7 +196,7 @@ export default function WerteForm({ onSuccess, selectedEntry }: WerteFormProps)
setFormData(prev => ({ ...prev, Zucker: e.target.value }))}
maxLength={4}
@@ -215,7 +215,7 @@ export default function WerteForm({ onSuccess, selectedEntry }: WerteFormProps)
setFormData(prev => ({ ...prev, Gewicht: e.target.value }))}
maxLength={4}
@@ -224,7 +224,7 @@ export default function WerteForm({ onSuccess, selectedEntry }: WerteFormProps)
|
setFormData(prev => ({ ...prev, DruckS: e.target.value }))}
maxLength={4}
@@ -233,7 +233,7 @@ export default function WerteForm({ onSuccess, selectedEntry }: WerteFormProps)
|
setFormData(prev => ({ ...prev, DruckD: e.target.value }))}
maxLength={4}
@@ -242,7 +242,7 @@ export default function WerteForm({ onSuccess, selectedEntry }: WerteFormProps)
|
setFormData(prev => ({ ...prev, Puls: e.target.value }))}
maxLength={4}
diff --git a/next.config.ts b/next.config.ts
index 225e495..0ea3461 100644
--- a/next.config.ts
+++ b/next.config.ts
@@ -1,7 +1,11 @@
import type { NextConfig } from "next";
+import path from "path";
const nextConfig: NextConfig = {
output: 'standalone',
+ turbopack: {
+ root: path.resolve(__dirname),
+ },
};
export default nextConfig;
diff --git a/package.json b/package.json
index e23f26c..2d45816 100644
--- a/package.json
+++ b/package.json
@@ -1,6 +1,6 @@
{
"name": "werte_next",
- "version": "1.1.2",
+ "version": "1.1.3",
"private": true,
"scripts": {
"dev": "next dev",
diff --git a/middleware.ts b/proxy.ts
similarity index 95%
rename from middleware.ts
rename to proxy.ts
index 06f2505..f497e6b 100644
--- a/middleware.ts
+++ b/proxy.ts
@@ -5,10 +5,10 @@ import { jwtVerify } from 'jose';
const SESSION_COOKIE_NAME = 'auth_session';
/**
* Middleware to protect routes with authentication
* Reusable for other projects - just copy this file
*/
-export async function middleware(request: NextRequest) {
+export async function proxy(request: NextRequest) {
const { pathname } = request.nextUrl;
// Check if authentication is enabled
|
@@ -5,10 +5,10 @@ import { jwtVerify } from 'jose';
const SESSION_COOKIE_NAME = 'auth_session';
/**
- * Middleware to protect routes with authentication
+ * Proxy to protect routes with authentication
* Reusable for other projects - just copy this file
*/